@@ -10,13 +10,13 @@ use warnings;
 use base qw( Tickit::Widget );
 use Tickit::Style;
 Tickit::Widget->VERSION( '0.35' );
-Tickit::Window->VERSION( '0.42' );
+Tickit::Window->VERSION( '0.57' );  # ->bind_event
 
 use Tickit::Window;
 use Tickit::Utils qw( textwidth );
 use Tickit::RenderBuffer;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Carp;
 
@@ -1103,9 +1103,9 @@ sub update_indicators
       }
       elsif( $self->window ) {
          $floatwin = $win->make_float( $line, $win->cols - $textwidth, 1, $textwidth );
-         $floatwin->set_on_expose( with_rb => sub {
-            my ( undef, $rb, $rect ) = @_;
-            $rb->text_at( 0, 0,
+         $floatwin->bind_event( expose => sub {
+            my ( $win, undef, $info ) = @_;
+            $info->rb->text_at( 0, 0,
                $self->{$text_field},
                $self->get_style_pen( "indicator" )
             );
